@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = '3.33_04';
+our $VERSION = '3.33_05';
 
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG; }   # set DEBUG level
 
@@ -13,7 +13,8 @@ our $SLEEPY = 1 if !defined $SLEEPY and $^O =~ /mswin|mac/i;
   # flag to occasionally sleep for $SLEEPY - 1 seconds.
 
 our $MAX_VERSION_WITHIN ||= 60;
-my $IS_CASE_INSENSITIVE = -e uc __FILE__ && -e lc __FILE__;
+my $IS_CASE_INSENSITIVE     = -e uc __FILE__ && -e lc __FILE__;
+my @DEFAULT_FILE_EXTENSIONS = ('', '.pod', '.pm', '.pl', 'plx');
 
 #############################################################################
 
@@ -43,6 +44,7 @@ sub init {
   $self->inc(1);
   $self->recurse(1);
   $self->verbose(DEBUG);
+  $self->file_extensions(@DEFAULT_FILE_EXTENSIONS);
   return $self;
 }
 
@@ -146,6 +148,7 @@ sub _make_search_callback {
       $files_for = sub { my $n = $_[0]; grep { $path2name->{$_} eq $n } %{ $path2name } };
   }
 
+  my $ext_re = $self->_file_extensions_re;
   my($file, $shortname, $isdir, $modname_bits);
   return sub {
     ($file, $shortname, $isdir, $modname_bits) = @_;
@@ -187,14 +190,14 @@ sub _make_search_callback {
     # Make sure it's a file even worth even considering
     if($laborious) {
       unless(
-        m/\.(pod|pm|plx?)\z/i || -x _ and -T _
+        m/\.($ext_re)\z/i || -x _ and -T _
          # Note that the cheapest operation (the RE) is run first.
       ) {
         $verbose > 1 and print " Brushing off uninteresting $file\n";
         return;
       }
     } else {
-      unless( m/^[-_a-zA-Z0-9]+\.(?:pod|pm|plx?)\z/is ) {
+      unless( m/^[-_a-zA-Z0-9]+(?:$ext_re)\z/is ) {
         $verbose > 1 and print " Brushing off oddly-named $file\n";
         return;
       }
@@ -585,7 +588,7 @@ sub find {
     my $fullname = File::Spec->catfile( $dir, @parts );
     print "Filename is now $fullname\n" if $verbose;
 
-    foreach my $ext ('', '.pod', '.pm', '.pl') {   # possible extensions
+    foreach my $ext ($self->file_extensions) {
       my $fullext = $fullname . $ext;
       if ( -f $fullext and $self->contains_pod($fullext) ) {
         print "FOUND: $fullext\n" if $verbose;
@@ -655,6 +658,22 @@ sub contains_pod {
 
 #==========================================================================
 
+sub file_extensions {
+  my $self = shift;
+
+  if (@_ > 0) {
+    $self->{file_extensions} = [@_];
+  }
+  return @{ $self->{file_extensions} };
+}
+
+sub _file_extensions_re {
+  my $self = shift;
+  return join('|', map { "\Q$_\E" } $self->file_extensions);
+}
+
+#==========================================================================
+
 sub _accessorize {  # A simple-minded method-maker
   shift;
   no strict 'refs';
@@ -875,6 +894,20 @@ include it in case it might prove useful for someone somewhere.
 and usually dir_prefix.)
 
 
+=item $search->file_extensions( I<list-of-strings> );
+
+Used to query or override the list of filename extensions
+considered when the C<survey> and C<find> methods are
+looking for files containing pod.
+
+The default list of extensions is:
+
+ '', '.pod', '.pm', '.pl', 'plx'
+
+Note that the order of the filename extensions is relevant:
+a C<.pod> file will be taken ahead of the associated C<.pm> file
+by C<find>.
+
 =item $search->progress( I<some-progress-object> );
 
 If you set a value for this attribute, the value is expected
